% fig_08_10
% plot four terms for the normalized displacements, ux/b and uy/b
% on a circuit around the edge dislocation at r = 10b
% Weertman & Weertman (1964)
% equations (8.36) and (8.37)

clear all, clf reset; % clear memory and figures
r = 10; % Radius of the circuit
mu = 30000; pr = 0.25; lm = (2*mu*pr)/(1-2*pr); % Elastic moduli
c1 = (0.5*mu)/(lm+2*mu); c2 = (lm+mu)/(lm+2*mu);
TH = 0:pi/180:2*pi; THD = TH*180/pi; % Angle theta
[XC,YC] = pol2cart(TH,r); % Convert polar to Cartesian coordinates
UX1 = -(1/(2*pi))*atan2(YC,XC);
UX2 = -(1/(2*pi))*c2*(XC.*YC)./(XC.^2+YC.^2);
UY1 = -(1/(2*pi))*(-c1).*log(XC.^2+YC.^2);
UY2 = -(1/(2*pi))*c2*(YC.^2)./(XC.^2+YC.^2);
plot(THD,UX1,THD,UX2,THD,UY1,THD,UY2);
axis([0 360 -.6 .6]);
xlabel('theta (degrees)'); ylabel('normalized displacement terms, u/b');
legend('ux term 1','ux term 2','uy term 1','uy term 2');