% fig_08_11
% plot Cartesian stress components near the edge dislocation
% Weertman & Weertman (1964)
% equations (8.41) - (8.43)

clear all, clf reset; % clear memory and figures
b = 1e-6; % b is Burgers vector
mu = 30000; pr = 0.25; lm = (2*mu*pr)/(1-2*pr); % Elastic moduli
c1 = b/(2*pi); c2 = 2*mu*(mu+lm)/(2*mu+lm);
x = linspace(-0.0001,0.0001,100)+eps;
y = linspace(-0.0001,0.0001,100);
[X,Y]=meshgrid(x,y); % define Cartesian grid
DEN = (X.^2 + Y.^2).^2;
SXX = c1*c2*((Y.*(3*X.^2 + Y.^2))./DEN);
SYY = -c1*c2*((Y.*(X.^2 - Y.^2))./DEN);
SXY = -c1*c2*((X.*(X.^2 - Y.^2))./DEN);
[T,R] = cart2pol(X,Y); % R is radial distance from dislocation
SXX(find(R<(5*b))) = nan; % avoid dislocation core (R < 5b)
SYY(find(R<(5*b))) = nan; SXY(find(R<(5*b))) = nan;

% plot contour maps
contourf(X,Y,SXX,25), axis equal ij tight, colormap(jet)
title('stress sxx'), xlabel('x/b'), ylabel('y/b'), colorbar
figure, contourf(X,Y,SYY,25), axis equal ij tight, colormap(jet)
title('stress syy'), xlabel('x/b'), ylabel('y/b'), colorbar
figure, contourf(X,Y,SXY,25), axis equal ij tight, colormap(jet)
title('stress sxy'), xlabel('x/b'), ylabel('y/b'), colorbar

% plot 3D surfaces
%figure, surf(X,Y,SXX), colorbar
%xlabel('x/b'), ylabel('y/b'), zlabel('stress sxx')
%figure, surf(X,Y,SYY), colorbar
%xlabel('x/b'), ylabel('y/b'), zlabel('stress syy')
%figure, surf(X,Y,SXY), colorbar
%xlabel('x/b'), ylabel('y/b'), zlabel('stress sxy')