% fig_08_18
% plot Cartesian stress and strain components
% in a rectangular region with traction free surface
% Hafner (1951)
% equations (8.60), (8.61), and (8.69)-(8.70)

clear all, clf reset; % clear memory and figures
cc = 0.013335; % cc (MPa/m) is the gradient in tectonic stress 
rg = 0.02667; % rg is the unit weight of rock (MPa/m)
ym = 30000; pr = 0.25; % Young's modulus (MPa) and Poission's ratio

M = 10; N = 10; % number of rows and columns for grid
x = linspace(0,10000,N); y = linspace(0,-10000,M);
[X,Y]=meshgrid(x,y); % define Cartesian grid

% compute and contour the lithostatic, tectonic, and 
% total stress components: SXXL, SXXT, and SXX
SXXL = rg*Y; SXXT = cc*X; SXX = cc*X + rg*Y;
contourf(X,Y,SXXL,10), axis equal tight
title('SXXL'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,SXXT,10), axis equal tight
title('SXXT'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,SXX,10), axis equal tight
title('SXX'), xlabel('x'), ylabel('y'), colorbar

% compute and contour the ambient = total stress component: SYY
SYY = rg*Y;
figure, contourf(X,Y,SYY,10), axis equal tight
title('SYY'), xlabel('x'), ylabel('y'), colorbar

% compute and contour the tectonic = total stress component: SXY
SXY = -cc*Y;
figure, contourf(X,Y,SXY,10), axis equal tight
title('SXY'), xlabel('x'), ylabel('y'), colorbar

% compute and contour the tectonic strain components:
% EXXT, EYYT, and EXYT
EXXT = (1 - pr^2)*cc*X/ym; 
EYYT = (pr + pr^2)*cc*X/ym;
EXYT = (1 + pr)*cc*Y/ym;
figure, contourf(X,Y,EXXT,10), axis equal tight
title('EXXT'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,EYYT,10), axis equal tight
title('EYYT'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,EXYT,10), axis equal tight
title('EXYT'), xlabel('x'), ylabel('y'), colorbar