% fig_08_19
% plot Cartesian tectonic displacements
% in a rectangular region with traction free surface
% Hafner (1951)
% equations (8.69)-(8.70)

clear all, clf reset; % clear memory and figures
cc = 0.1; % (MPa/m) gradient in tectonic stress 
c3 = 0; % (m/m) gradient in displacement for rigid rotation
c6 = 0; % (m) rigid translation in x
c7 = 0; % (m) rigid translation in y
ym = 30000; pr = 0.25; % Young's modulus (MPa) and Poission's ratio

M = 10; N = 10; % number of rows and columns for grid
x = linspace(0,10000,N); y = linspace(0,-10000,M);
[X,Y]=meshgrid(x,y); % define Cartesian grid

% compute and plot the tectonic displacement components: UX, UY
UX = (((1-pr^2)/ym)*0.5*cc*X.^2) - (((2+pr-pr^2)/ym)*0.5*cc*Y.^2) - c3*Y + c6;
UY = -(((pr+pr^2)/ym)*cc*X.*Y) + c3*X + c7;
UX0 = eps*UX; UY0 = eps*UY;
quiver(X,Y,UX,UY0,1), axis equal tight
figure, quiver(X,Y,UX0,UY,1), axis equal tight

% plot the displacement vector U
figure, quiver(X,Y,UX,UY,1), axis equal tight
title('Displacement'), xlabel('x'), ylabel('y')