% fig_08_22
% plot polar stress components near the half-circular valley
% under lithostatic stress loading
% Michell (1899)
% equation (8.90)

clear all, clf reset; % clear memory and figures
rad = 1000; % valley radius, m
rhog = 0.025; % weight per unit volume, MPa/m
x = linspace(0,5000,100)+eps; % add eps to avoid singularity at origin
y = linspace(0,-5000,100); 
[X,Y] = meshgrid(x,y); % define Cartesian grid
[TH,R] = cart2pol(X,Y); % convert to polar coordinates
SRRV = -(rhog*R.*sin(TH)).*((rad./R).^2); % stress due to valley
SRRV(find(R<rad)) = nan; % avoid grid points within valley
SRR = (rhog*R.*sin(TH)).*(1-(rad./R).^2); % add lithostatice stress 
STT = rhog*R.*sin(TH);
SRR(find(R<rad)) = nan; STT(find(R<rad)) = nan;
%figure, surf(X,Y,SRRV), xlabel('x-axis'), ylabel('y-axis'), zlabel('stress srrv')
%figure, surf(X,Y,SRR), xlabel('x-axis'), ylabel('y-axis'), zlabel('stress srr')
%figure, surf(X,Y,STT), xlabel('x-axis'), ylabel('y-axis'), zlabel('stress stt')

% plot filled contour maps of stresses 
contourf(X,Y,SRRV,10), colorbar
axis equal, axis tight, title('stress srr (valley)')
figure, contourf(X,Y,SRR,10), colorbar
axis equal, axis tight, title('stress srr=s1')
figure, contourf(X,Y,STT,10), colorbar
axis equal, axis tight, title('stress stt=s2')

% Cartesian components
STH = sin(TH); STH2 = STH.^2; CTH = cos(TH); CTH2 = CTH.^2;
SXX = SRR.*CTH2+STT.*STH2;
SYY = SRR.*STH2+STT.*CTH2;
SXY = (SRR-STT).*CTH.*STH;
figure, subplot(2,2,1), contourf(X,Y,SXX,10), colorbar, title('stress sxx')
subplot(2,2,3), contourf(X,Y,SYY,10), colorbar, title('stress syy')
subplot(2,2,4), contourf(X,Y,SXY,10), colorbar, title('stress sxy')
% S1 = 0.5*(SXX+SYY)+sqrt(((0.25*(SXX-SYY).^2)+SXY.^2));
% S2 = 0.5*(SXX+SYY)-sqrt(((0.25*(SXX-SYY).^2)+SXY.^2));
% figure, subplot(2,2,3), contourf(X,Y,S1,10), colorbar, title('stress s1')
% subplot(2,2,4), contourf(X,Y,S2,10), colorbar, title('stress s2')
G1 = 0.5*atan2(2*SXY,SXX-SYY); 
G1(find(R<rad)) = nan; U = cos(G1); V = sin(G1);
figure, quiver(X,Y,U,V,.4,'.'), axis equal
