% fig_08_28
% plot polar stress components at boundary of circular inclusion
% Jaeger and Cook (1979)
% equations (8.96)-(8.97) and (8.100) - (8.102)

clear all, clf reset; % clear memory and figures
ri = 1; s1 = 1; s3 = -1;
pri = 0.2; prs = 0.3; ki = 3-4*pri; ks = 3-4*prs;
mui = 10000; mus = 30000; k = mui/mus;
num1 = (k*(ks+2)+ki)*k*(ks+1); num2 = (k*(ks-2)-ki+2)*k*(ks+1);
den = 2*(2*k+ki-1)*(k*ks+1);
SXX = (num1/den)*s1+(num2/den)*s3;
SYY = (num2/den)*s1+(num1/den)*s3;
R = 1;
TH = 0:pi/30:2*pi; THD = TH*180/pi;
ST = sin(TH); S2T = sin(2*TH); ST2 = ST.^2; 
CT = cos(TH); C2T = cos(2*TH); CT2 = CT.^2;
SRRI = SXX.*CT2+SYY.*ST2;
SRTI = -(SXX-SYY).*CT.*ST;
a = 2*(1-k)/(k*ks+1); b = (ki-1-k*(ks-1))/(2*k+ki-1); c = (k-1)/(k*ks+1);
R2 = (ri./R).^2; R4 = R2.^2;
SRR = (0.5*(s1+s3)*(1-b*R2))+(0.5*(s1-s3)*((1-2*a*R2-3*c*R4).*C2T));
SRT = (-0.5*(s1-s3)*((1+a*R2+3*c*R4).*S2T));
plot(THD,SRRI,THD,SRTI,THD,SRR,'x',THD,SRT,'x');
axis([0 360 -1 1]);
xlabel('theta (degrees)'); ylabel('stress');
legend('SRRI','SRTI','SRR','SRT');