% fig_08_29
% plot Cartesian stress components within and near the circular inclusion
% Jaeger and Cook (1979)
% equations (8.96)-(8.97) and (8.100) - (8.102)

clear all, clf reset; % clear memory and figures
ri = 1; s1 = 1; s3 = 0;
pri = 0.25; prs = 0.25; ki = 3-4*pri; ks = 3-4*prs;
mui = 10000; mus = 30000; k = mui/mus;
num1 = (k*(ks+2)+ki)*k*(ks+1); num2 = (k*(ks-2)-ki+2)*k*(ks+1);
den = 2*(2*k+ki-1)*(k*ks+1);
a = 2*(1-k)/(k*ks+1); b = (ki-1-k*(ks-1))/(2*k+ki-1); c = (k-1)/(k*ks+1);
x = linspace(-4,4,320); y = linspace(-4,4,320);
[X,Y] = meshgrid(x,y);
[TH,R] = cart2pol(X,Y);
ST = sin(TH); S2T = sin(2*TH); ST2 = ST.^2; 
CT = cos(TH); C2T = cos(2*TH); CT2 = CT.^2;
R2 = (ri./R).^2; R4 = R2.^2;
SRR = (0.5*(s1+s3)*(1-b*R2))+(0.5*(s1-s3)*((1-2*a*R2-3*c*R4).*C2T));
STT = (0.5*(s1+s3)*(1+b*R2))-(0.5*(s1-s3)*((1-3*c*R4).*C2T));
SRT = (-0.5*(s1-s3)*((1+a*R2+3*c*R4).*S2T));
SRR(R<1) = nan; STT(R<1) = nan; SRT(R<1) = nan;
contourf(X,Y,SRR,10), colorbar, title('stress srr')
figure, contourf(X,Y,STT,10), colorbar, title('stress stt')
figure, contourf(X,Y,SRT,10), colorbar, title('stress srt')
% Cartesian components
SXX = SRR.*CT2+STT.*ST2-2*SRT.*CT.*ST;
SYY = SRR.*ST2+STT.*CT2+2*SRT.*CT.*ST;
SXY = (SRR-STT).*CT.*ST+SRT.*(CT2-ST2);
SXX(R<1) = (num1/den)*s1+(num2/den)*s3;
SYY(R<1) = (num2/den)*s1+(num1/den)*s3;
SXY(R<1) = 0;
figure, contourf(X,Y,SXX,10), axis equal, axis tight
colorbar, title('stress sxx')%, colormap(gray)
figure, contourf(X,Y,SYY,10),  axis equal, axis tight
colorbar, title('stress syy')%, colormap(gray)
figure, contourf(X,Y,SXY,10),  axis equal, axis tight
colorbar, title('stress sxy')%, colormap(gray)